@@ -151,8 +151,16 @@ int MyConnect(dbh_t *sock, char* host, char* port, char* user,
 	 *  Setting a port for mysql's client is ugly: We have to use
 	 *  the not documented variable mysql_port.
 	 */
-        mysql_port = portNr;
-        return mysql_connect(*sock, host, user, password) ? TRUE : FALSE;
+        int result, oldPort = 0;
+	if (portNr) {
+	    oldPort = mysql_port;
+	    mysql_port = portNr;
+	}
+        result = mysql_connect(*sock, host, user, password) ? TRUE : FALSE;
+	if (oldPort) {
+	    mysql_port = oldPort;
+	}
+	return result;
 #else
 #if defined(MYSQL_VERSION_ID)  &&  MYSQL_VERSION_ID >= 032115
 	return mysql_real_connect(*sock, host, user, password, portNr, NULL,
